![](/hugr/assets/hugr_logo.svg)

# hugr-core

[![build_status][]](https://github.com/quantinuum/hugr/actions)
[![crates][]](https://crates.io/crates/hugr-core)
[![msrv][]](https://github.com/quantinuum/hugr)
[![codecov][]](https://codecov.io/gh/quantinuum/hugr)

Internal core definitions for the `hugr` package.
Refer to the [main crate](http://crates.io/crates/hugr) for more information.

Please read the [API documentation here][].

## Experimental Features

- `declarative`:
  Experimental support for declaring extensions in YAML files, support is limited.

## Recent Changes

See [CHANGELOG][] for a list of changes. The minimum supported rust
version will only change on major releases.

## Development

See [DEVELOPMENT.md](https://github.com/quantinuum/hugr/blob/main/DEVELOPMENT.md) for instructions on setting up the development environment.

## License

This project is licensed under Apache License, Version 2.0 ([LICENSE][] or http://www.apache.org/licenses/LICENSE-2.0).

[API documentation here]: https://docs.rs/hugr-core/
[build_status]: https://github.com/quantinuum/hugr/actions/workflows/ci-rs.yml/badge.svg?branch=main
[msrv]: https://img.shields.io/crates/msrv/hugr-core
[crates]: https://img.shields.io/crates/v/hugr-core
[codecov]: https://img.shields.io/codecov/c/gh/quantinuum/hugr?logo=codecov
[LICENSE]: https://github.com/quantinuum/hugr/blob/main/LICENCE
[CHANGELOG]: https://github.com/quantinuum/hugr/blob/main/hugr-core/CHANGELOG.md
